#!/bin/sh 
#! test Java
#! Java dst testing for HP/UX
#! Author: Powell Hazzard (HP)
if [ -d $1 ] 
then
# we are directory, no need to test a directory name java
# return
exit 9
fi
#
if [ ! -x $1 ]
then
# not a java executable ignore it
   exit 9
fi
#
#! java directory checks
#!
DSTSUMMARYFILE=$2
if [ -e "$DSTSUMMARYFILE" ]
then
   JVMFOUND=`head -n 1 $DSTSUMMARYFILE | awk '{print $1}'`
   JVMPASSED=`head -n 1 $DSTSUMMARYFILE | awk '{print $2}'`
   JVMFAILED=`head -n 1 $DSTSUMMARYFILE | awk '{print $3}'`
   JVMUNSUPPORTED=`head -n 1 $DSTSUMMARYFILE | awk '{print $4}'`
else
    DSTSUMMARYFILE=/dev/null
   JVMFOUND=0
   JVMPASSED=0
   JVMFAILED=0
   JVMUNSUPPORTED=0
fi
WD=`dirname "$0"`
DIR=`dirname "$1"`
BASE=`basename "$1"`
if [ -d "$DIR/../bin" ] && [ -d "$DIR/../lib" ] && [ -f "$DIR/../lib/rt.jar" ]
then
   echo "Java found in: $DIR"
else
   # not java just return
   exit 9
fi
#
echo " "
echo "   Checking version..."
echo " "
#
# get version
#
OUTTMP=/tmp/dsttestingout.$$
ERRTMP=/tmp/dsttestingerr.$$
#
$1 -version 2>$OUTTMP 2>$ERRTMP 
VERS=`head -n 1 $ERRTMP | awk '{print $3}' | sed s/\"//g`
#
rm $ERRTMP $OUTTMP
echo "      Version:  $VERS"
echo " "
#
# Checking for non-numeric values in $VERS string, which indicates bad return 
# values in the Java Version String.  Old versions of Netscape for example...
# -RdR-
# 
MVERS=`echo $VERS | awk -F. '{ print $1 }'`
expr "$MVERS" + 1 >/dev/null 2>&1
if [ $? -ge 2 ]
then
  echo " ATTENTION! - Version: $VERS, is not valid." 
  echo " A Manual check of: $DIR" 
  echo " May be required."
  echo " Continuing..."
  echo " "
exit 9
fi
#
#
MAJORVERS=`echo $VERS | awk -F. '{ print $1 "." $2 "." $3 }' | awk -F- '{print $1}'`
#MAJORVERS=`echo ${VERS%.*}`
# compare versions
#echo $MAJORVERS
case $MAJORVERS in
    1.2.2)
	echo " "
	echo "      Notice: Java version 1.2.2 is no longer supported."
	echo "              Java Upgrade is needed to support new DST rules."
	echo " "
	JVMFOUND=`expr $JVMFOUND + 1`
	JVMUNSUPPORTED=`expr $JVMUNSUPPORTED + 1`
        JVMFAILED=`expr $JVMFAILED + 1`
	echo "$JVMFOUND $JVMPASSED $JVMFAILED $JVMUNSUPPORTED" > $DSTSUMMARYFILE
	exit 0
	;;
    1.3.0)
	echo " "
	echo "      Notice: Java version 1.3.0 is no longer supported."
	echo "              Java Upgrade is needed to support new DST rules."
	echo " "
	JVMFOUND=`expr $JVMFOUND + 1`
	JVMUNSUPPORTED=`expr $JVMUNSUPPORTED + 1`
        JVMFAILED=`expr $JVMFAILED + 1`
        echo "$JVMFOUND $JVMPASSED $JVMFAILED $JVMUNSUPPORTED" > $DSTSUMMARYFILE
	exit 0
	;;
    1.4.0)
	echo " "
	echo " Notice: Java version 1.4.0 is no longer supported."
	echo "         Java Upgrade is needed to support new DST rules."
	echo "         However, TZUpdater may also be applied. "
	echo "         Continue with Tests..."
	echo " "
	JVMUNSUPPORTED=`expr $JVMUNSUPPORTED + 1`
	;;
    1.4.1)
	echo " "
	echo " Notice: Java version 1.4.1 is no longer supported."
	echo "         Java Upgrade is needed to support new DST rules."
	echo "         However, TZUpdater may also be applied. "
	echo "         Continue with Tests..."
	echo " "
	JVMUNSUPPORTED=`expr $JVMUNSUPPORTED + 1`
	;;
   Execute)
	echo " "
	echo "WARNING: Execute permission denied, check permissions?"
	echo "         Unable to test Java located at $DIR"
	echo " "
	exit 9
esac
echo " "
echo "      Testing U.S. & Canada DST results with this version of Java: $VERS "
echo " "
# 
#if [ -f ./DstTest.class ]
#then
#   echo "DstJava class file aready built, continuing..."
#   echo " "
#else
#   echo "Building DstJava Class file, please wait..."
#   javac ./DstJava.java
#   echo "Done!  Continuing..."
#   echo " " 
#fi
#
# execute Java DST test
#
$1 -cp $WD DstTest 2>/dev/null
KEEPSTATUS=$?
if [ $KEEPSTATUS -eq 0 ]
 then
    echo "    "
    echo "      Status Passed - No DST issues found! "
    echo " "
    JVMFOUND=`expr $JVMFOUND + 1`
    JVMPASSED=`expr $JVMPASSED + 1`
    echo "$JVMFOUND $JVMPASSED $JVMFAILED $JVMUNSUPPORTED" > $DSTSUMMARYFILE
    exit 0
else
    JVMFOUND=`expr $JVMFOUND + 1`
#    if [ $KEEPSTATUS -eq 12 ] 
#   then
#      JVMPASSED=`expr $JVMPASSED + 1024`
#   fi
    JVMFAILED=`expr $JVMFAILED + 1`
    echo "$JVMFOUND $JVMPASSED $JVMFAILED $JVMUNSUPPORTED" > $DSTSUMMARYFILE
fi
#
MAJORVERS=`echo $MAJORVERS | awk -F. '{ print $1 "." $2}'`
#MAJORVERS=`echo ${MAJORVERS%.*}`

case $MAJORVERS in
    1)
	echo " "
        echo "      Status Failed - DST issue found either with U.S. or Canada"
        echo " "
        echo "     Recommendation:"
        echo " "
	echo "      Please upgrade to the latest version of Java 1.5 or,"
	echo "      Run the TZUpdater for Java 1.5.0 "
	echo " "
        exit 0
        ;;
    1.5)
        echo " "
        echo "      Status Failed - DST issue found either with U.S. or Canada"
        echo " "
        echo "     Recommendation:"
        echo " "
	echo "      Please upgrade to the latest version of Java 1.5 or,"
	echo "      Run the TZUpdater for Java 1.5.0 "
	echo " "
        exit 0
        ;;
    1.4)
        echo " "
        echo "      Status Failed - DST issue found either with U.S. or Canada"
        echo " "
        echo "     Recommendation:"
        echo " "
	echo "      Please upgrade to the latest version of Java 1.4.2 or,"
	echo "      Run the TZUpdater for Java 1.4.* "
	echo " "
        exit 0
        ;;
    1.3)
	echo " "
	echo "      Status Failed - DST issue found either with U.S. or Canada"
	echo " "
	echo "     Recommendation:"
	echo " "
	echo "      Please upgrade to the latest version of Java 1.3.1 or,"
	echo "      Run the TZUpdater for Java 1.3.1 "
	echo " "
        exit 0
        ;;
esac

echo " "
echo "    Unknown error - please report this failure - version $MAJORVERS"
echo " "
exit 0
